* **What kind of change does this PR introduce?** (Language addition, bug fix, feature, docs update, ...)

<!-- Use below for adding new language -->
* **Checklist**
- [] Have you added adequate tests on epitran/test?
- [] Have you updated the language list in README.md?
- [] Does it follow the <iso639>-<iso15924> format?
- [] Have you used IPA ɡ, not latin small letter g?

* **Sources of information for the test samples** (I'm a native speaker, books, online resources, ...)


* **Sources of information for the rules** (I'm a native speaker, books, online resources, ...)


<!-- Use below for everything else -->
* **What is the current behavior?** (You can also link to an open issue here)


* **What is the new behavior (if this is a feature change)?**


* **Does this PR introduce a breaking change?** (What changes might users need to make in their application due to this PR?)


